# -*- mode: python; tab-width: 4; indent-tabs-mode: nil; py-indent-offset: 4; -*-
# vim:ft=python:et:sw=4:ts=4

"""
U{Python Commons<http://assorted.sf.net/python-commons>} is a
general-purpose library.

@author: Yang Zhang
@copyright: Yang Zhang unless otherwise noted
@license: PSF
"""

__version__ = ( 0, 2, 0 )
__all__ = [ 'async',
            'control',
            'decs',
            'environ',
            'exceps',
            'files',
            'interp',
            'log',
            'misc',
            'networking',
            'progress',
            'seqs',
            'servers',
            'startup',
            'strs',
            'structs',
            'threads',
            'trace' ]

# TODO more resources:
# http://aima.cs.berkeley.edu/python/utils.py
# http://aspn.activestate.com/ASPN/Cookbook/Python
# http://aspn.activestate.com/ASPN/Cookbook/Python?&recipe_status=editors
# http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/413486
# interesting:
# http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/259174
# http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/473790
